@@ -1,8 +1,8 @@
 package XFST::Lookup;
 
-# $Header: /var/cvsroot/XFST-Lookup/lib/XFST/Lookup.pm,v 1.15 2005/06/14 20:03:14 alex Exp $
+# $Header: /var/cvsroot/XFST-Lookup/lib/XFST/Lookup.pm,v 1.17 2005/06/27 16:24:12 alex Exp $
 
-$VERSION="0.5";
+$VERSION="0.6";
 
 use strict;
 use Carp;
@@ -274,7 +274,7 @@ sub lookup {
     # TODO: what about win32? :(
     my $dest_stream;
     ( $self->{debug} == 1 ) ? $dest_stream = '&2' :  
-        ( ( $^O =~ /linux|bsd|mac/i ) ?
+        ( ( $^O =~ /linux|bsd|darwin/i ) ?
             $dest_stream = '&2' : $dest_stream = '/dev/null' );
     
     # using fork() and stuff in order to get rid of File::Temp...
